==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WeChatConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WeChatConfigBuilder extends WeChatConfigFluentImpl<WeChatConfigBuilder> implements VisitableBuilder<WeChatConfig,WeChatConfigBuilder>{
  public WeChatConfigBuilder() {
    this(false);
  }
  public WeChatConfigBuilder(Boolean validationEnabled) {
    this(new WeChatConfig(), validationEnabled);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WeChatConfig(), validationEnabled);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent,WeChatConfig instance) {
    this(fluent, instance, false);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent,WeChatConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAgentID(instance.getAgentID());
      fluent.withApiSecret(instance.getApiSecret());
      fluent.withApiURL(instance.getApiURL());
      fluent.withCorpID(instance.getCorpID());
      fluent.withHttpConfig(instance.getHttpConfig());
      fluent.withMessage(instance.getMessage());
      fluent.withMessageType(instance.getMessageType());
      fluent.withSendResolved(instance.getSendResolved());
      fluent.withToParty(instance.getToParty());
      fluent.withToTag(instance.getToTag());
      fluent.withToUser(instance.getToUser());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public WeChatConfigBuilder(WeChatConfig instance) {
    this(instance,false);
  }
  public WeChatConfigBuilder(WeChatConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAgentID(instance.getAgentID());
      this.withApiSecret(instance.getApiSecret());
      this.withApiURL(instance.getApiURL());
      this.withCorpID(instance.getCorpID());
      this.withHttpConfig(instance.getHttpConfig());
      this.withMessage(instance.getMessage());
      this.withMessageType(instance.getMessageType());
      this.withSendResolved(instance.getSendResolved());
      this.withToParty(instance.getToParty());
      this.withToTag(instance.getToTag());
      this.withToUser(instance.getToUser());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  WeChatConfigFluent<?> fluent;
  Boolean validationEnabled;
  public WeChatConfig build() {
    WeChatConfig buildable = new WeChatConfig(fluent.getAgentID(),fluent.getApiSecret(),fluent.getApiURL(),fluent.getCorpID(),fluent.getHttpConfig(),fluent.getMessage(),fluent.getMessageType(),fluent.getSendResolved(),fluent.getToParty(),fluent.getToTag(),fluent.getToUser());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WeChatConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WeChatConfigBuilder extends WeChatConfigFluent<WeChatConfigBuilder> implements VisitableBuilder<WeChatConfig,WeChatConfigBuilder>{
  public WeChatConfigBuilder() {
    this(false);
  }
  public WeChatConfigBuilder(Boolean validationEnabled) {
    this(new WeChatConfig(), validationEnabled);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WeChatConfig(), validationEnabled);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent,WeChatConfig instance) {
    this(fluent, instance, false);
  }
  public WeChatConfigBuilder(WeChatConfigFluent<?> fluent,WeChatConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new WeChatConfig());

    if (instance != null) {
      fluent.withAgentID(instance.getAgentID());
      fluent.withApiSecret(instance.getApiSecret());
      fluent.withApiURL(instance.getApiURL());
      fluent.withCorpID(instance.getCorpID());
      fluent.withHttpConfig(instance.getHttpConfig());
      fluent.withMessage(instance.getMessage());
      fluent.withMessageType(instance.getMessageType());
      fluent.withSendResolved(instance.getSendResolved());
      fluent.withToParty(instance.getToParty());
      fluent.withToTag(instance.getToTag());
      fluent.withToUser(instance.getToUser());
      fluent.withAgentID(instance.getAgentID());
      fluent.withApiSecret(instance.getApiSecret());
      fluent.withApiURL(instance.getApiURL());
      fluent.withCorpID(instance.getCorpID());
      fluent.withHttpConfig(instance.getHttpConfig());
      fluent.withMessage(instance.getMessage());
      fluent.withMessageType(instance.getMessageType());
      fluent.withSendResolved(instance.getSendResolved());
      fluent.withToParty(instance.getToParty());
      fluent.withToTag(instance.getToTag());
      fluent.withToUser(instance.getToUser());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public WeChatConfigBuilder(WeChatConfig instance) {
    this(instance,false);
  }
  public WeChatConfigBuilder(WeChatConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new WeChatConfig());

    if (instance != null) {
      this.withAgentID(instance.getAgentID());
      this.withApiSecret(instance.getApiSecret());
      this.withApiURL(instance.getApiURL());
      this.withCorpID(instance.getCorpID());
      this.withHttpConfig(instance.getHttpConfig());
      this.withMessage(instance.getMessage());
      this.withMessageType(instance.getMessageType());
      this.withSendResolved(instance.getSendResolved());
      this.withToParty(instance.getToParty());
      this.withToTag(instance.getToTag());
      this.withToUser(instance.getToUser());
      this.withAgentID(instance.getAgentID());
      this.withApiSecret(instance.getApiSecret());
      this.withApiURL(instance.getApiURL());
      this.withCorpID(instance.getCorpID());
      this.withHttpConfig(instance.getHttpConfig());
      this.withMessage(instance.getMessage());
      this.withMessageType(instance.getMessageType());
      this.withSendResolved(instance.getSendResolved());
      this.withToParty(instance.getToParty());
      this.withToTag(instance.getToTag());
      this.withToUser(instance.getToUser());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  WeChatConfigFluent<?> fluent;
  Boolean validationEnabled;
  public WeChatConfig build() {
    WeChatConfig buildable = new WeChatConfig(fluent.getAgentID(),fluent.getApiSecret(),fluent.getApiURL(),fluent.getCorpID(),fluent.buildHttpConfig(),fluent.getMessage(),fluent.getMessageType(),fluent.getSendResolved(),fluent.getToParty(),fluent.getToTag(),fluent.getToUser());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
